%----------------------------------------------------------------------%
%                      Classe de documents Cast3M
%----------------------------------------------------------------------%

%--------------------------- Identification ----------------------------
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{Cast3M}[2011/04/01 Classe Documentation Cast3M]

%---------------------------- Code initial -----------------------------
\RequirePackage{babel}
\RequirePackage{xspace}

% Raccourci nom Cast3M
\newcommand{\castem}{Cast3M\xspace}
% Couleur bandeau et police entete page de garde
\newcommand{\@coulfondentete}{white}
\newcommand{\@coultextentete}{black}
% Texte entete page de garde
\newcommand{\@entete}{Type de document \castem}
% Choix de la langue
\newcommand{\@langue}{francais}

%---------------------- Declaration des options ------------------------
% Option de langue
\iflanguage{english}{\renewcommand{\@langue}{english}}

% Type de document : utiliser / exemples / developper
\DeclareOption{utiliser}{\renewcommand{\@coulfondentete}{blue}%
                         \renewcommand{\@coultextentete}{white}%
   \iflanguage{english}{\renewcommand{\@entete}{Using \castem}}%
                       {\renewcommand{\@entete}{Utiliser \castem}}}

\DeclareOption{exemples}{\renewcommand{\@coulfondentete}{white}%
   \iflanguage{english}{\renewcommand{\@entete}{\castem examples}}%
                       {\renewcommand{\@entete}{Exemples \castem}}}

\DeclareOption{developper}{\renewcommand{\@coulfondentete}{red}%
                           \renewcommand{\@coultextentete}{white}%
   \iflanguage{english}{\renewcommand{\@entete}{Developping \castem}}%
                       {\renewcommand{\@entete}{D\'evelopper \castem}}}

% Definition des options de classe par defaut
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}

%----------------------- Execution des options -------------------------
\ProcessOptions\relax

%---------------------- Chargement d'extensions ------------------------
% Extension de la classe book
\LoadClass[a4paper]{book}

% Packages a utiliser
\RequirePackage[latin1]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage{lmodern}
\RequirePackage{graphicx}
\RequirePackage{fancyhdr}
\RequirePackage{ifthen}
\RequirePackage{makeidx}
\RequirePackage{color}
\RequirePackage{pslatex}
\RequirePackage{longtable}
\RequirePackage[includefoot,nomarginpar,twoside, top=27mm,bottom=20mm,
head=5mm,headsep=7mm, footskip=7mm, hmargin=20mm,bindingoffset=0mm]{geometry}
\RequirePackage[bookmarks=true, breaklinks=true, hyperindex=true, dvips=true,
ps2pdf=true, colorlinks=true, linkcolor=black, anchorcolor=black,
citecolor=black, filecolor=black, menucolor=black, runcolor=black,
urlcolor=black, pdfstartview=Fit, pdfpagelayout=TwoPageRight]{hyperref}

%--------------------------- Code Principal ----------------------------
% Texte entetes corps du document
\newcommand{\@entetep}{\leftmark}
\newcommand{\entetep}[1]{\renewcommand{\@entetep}{#1}}

\newcommand{\@entetei}{\rightmark}
\newcommand{\entetei}[1]{\renewcommand{\@entetei}{#1}}

% Commande pour titre
\renewcommand{\@title}{\fontsize{48}{48}\selectfont\sc Titre}
\renewcommand{\title}[1]{\renewcommand{\@title}{\sc {#1}}}

% Commande pour champ auteur vide
\renewcommand{\@author}{\rule{0bp}{0bp}}
\renewcommand{\author}[1]{\renewcommand{\@author}{#1}}

% Commande pour champ remerciements
\newcommand{\@merci}{\rule{0bp}{0bp}}
\newcommand{\merci}[1]{\renewcommand{\@merci}{#1}}

% Legende tableaux
\newcommand{\topcaption}{%
  \setlength{\abovecaptionskip}{0pt}%
  \setlength{\belowcaptionskip}{10pt}%
  \caption}

% Largeur de page pour bandeau entete page de garde
\newlength{\pagewidth}
\setlength{\pagewidth}{595bp}
\newlength{\pageheight}
\setlength{\pageheight}{842bp}

% On redefinit la commande \maketitle
\renewcommand{\maketitle}{
   \begin{titlepage}
      \thispagestyle{empty}
      \begin{center}
         \setlength{\unitlength}{1bp}
         \begin{picture}(0,0)(0,754)
            \put(0,750){\makebox(0,0){\setlength{\fboxrule}{1bp}%
               \fcolorbox{\@coultextentete}{\@coulfondentete}{%
                  \rule{0bp}{60bp}\rule{\pagewidth}{0bp}%
            }}}%
            \put(0,750){\makebox(0,0){%
               \color{\@coultextentete}{\Huge\sc{\@entete}}%
            }}%
            \put(0,685){\makebox(0,0)[b]{\Huge\sc{\@author}}}%
            \put(0,670){\makebox(0,0){\rule{\pagewidth}{0.5bp}}}%
            \put(0,585){\makebox(0,0){\@title}}%
            \put(0,500){\makebox(0,0)[t]{%
               \includegraphics[height=240bp]{Logo_castem.eps}}}%
            \put(-220,50){\makebox(0,80)[b]{%
               \includegraphics[height=70bp]{Logo_cea_nb.eps}}}%
            \put(+255,65){\makebox(0,80)[br]{\sc\huge%
                \ifthenelse{\equal{\@langue}{english}}{ }%
                           {\'Edition} \@date}}%
         \end{picture}
      \end{center}
   \end{titlepage}
   \newpage
   \thispagestyle{empty}
   \begin{center}
      \small
      \@merci\\
      \vfill
      \ifthenelse{\equal{\@langue}{english}}{\castem~documentation~2011}%
                                            {Documentation \castem~2011}\\
      \rule[0.5ex]{15ex}{0.2bp}\\
      \url{http://www-cast3m.cea.fr}
   \end{center}
   \newpage
   \thispagestyle{empty}
   \begin{center}
   \mbox{~}\\
   \vspace{0.2\textheight}
   \mbox{\rule{0.9\textwidth}{0.5bp}}\\
   \mbox{~}\\
   \parbox{0.7\textwidth}{\ifthenelse{\equal{\@langue}{english}}
    {\input{identification_eng.tex}}
    {\input{identification_fra.tex}}
   }\\
   \mbox{~}\\
   \mbox{\rule{0.9\textwidth}{0.5bp}}
   \end{center}
   \newpage
   \thispagestyle{empty}
   \cleardoublepage
}

% En-tete et pied de page pour les pages normales
\pagestyle{fancy}
\fancyhf{}
\lhead[{\raisebox{0.05mm}[0pt]{\includegraphics[height=1cm]{Logo_cea_nb.eps}}}]
      {\@entetei}
%\chead[\@entetep]{\@entetei}
\rhead[\@entetep]
      {\raisebox{0.05mm}[0pt]{\includegraphics[height=1cm]{Logo_castem.eps}}}
%\cfoot{\thepage}
\rfoot[]{\hrulefill\\ \thepage}
\lfoot[\hrulefill\\ \thepage]{}

% On redefinit le style plain pour avoir les memes en-tete
% et pied de page pour les pages speciales
\fancypagestyle{plain}{
\lhead[{\raisebox{0.05mm}[0pt]{\includegraphics[height=1cm]{Logo_cea_nb.eps}}}]
      {\@entetei}
%\chead[\@entetep]{\@entetei}
\rhead[\@entetep]
      {\raisebox{0.05mm}[0pt]{\includegraphics[height=1cm]{Logo_castem.eps}}}
%\cfoot{\thepage}
\rfoot[]{\hrulefill\\ \thepage}
}

% On peut modifier ici la numerotation des titres
\renewcommand\thepart           {\@Roman\c@part}
\renewcommand\thechapter        {\@arabic\c@chapter}
\renewcommand\thesection        {\thechapter.\@arabic\c@section}
\renewcommand\thesubsection     {\thesection.\@arabic\c@subsection}
\renewcommand\thesubsubsection  {\thesubsection.\@arabic\c@subsubsection}
\renewcommand\theparagraph      {\thesubsubsection.\@arabic\c@paragraph}
\renewcommand\thesubparagraph   {\theparagraph.\@arabic\c@subparagraph}


